@@ -16,7 +16,7 @@ use App::Memcached::CLI::DataSource;
 use App::Memcached::CLI::Item;
 use App::Memcached::CLI::Util ':all';
 
-use version; our $VERSION = 'v0.5.3';
+use version; our $VERSION = 'v0.5.4';
 
 my $PROGRAM = basename $0;
 
@@ -195,9 +195,9 @@ sub help {
             summary => 'Show cachedump of specified slab',
             description => <<'EODESC',
 Usage:
-    > cachedump <CLASS> <NUMBER>
+    > cachedump <CLASS> [<NUMBER>]
     > cachedump 1 10
-    > cachedump 3     # default <NUMBER>
+    > cachedump 3     # show default number of items
 EODESC
         },
         +{
@@ -225,7 +225,7 @@ EODESC
         },
         +{
             command => 'get',
-            summary => 'Get data of KEY',
+            summary => 'Get data by KEY',
             description => <<'EODESC',
 Usage:
     > get <KEY>
@@ -233,7 +233,7 @@ EODESC
         },
         +{
             command => 'set',
-            summary => 'Set data with KEY, VALUE',
+            summary => 'Set data by KEY VALUE',
             description => <<'EODESC',
 Usage:
     > set <KEY> <VALUE> [<EXPIRE> [<FLAGS>]]
@@ -244,7 +244,7 @@ EODESC
         },
         +{
             command => 'delete',
-            summary => 'Delete data of KEY',
+            summary => 'Delete data by KEY',
             description => <<'EODESC',
 Usage:
     > delete <KEY>
@@ -500,8 +500,8 @@ App::Memcached::CLI::Main - Interactive/Batch CLI for Memcached
 =head1 SYNOPSIS
 
     use App::Memcached::CLI::Main;
-    my $params = App::Memcached::CLI->parse_args;
-    App::Memcached::CLI->new(%$params)->run;
+    my $params = App::Memcached::CLI::Main->parse_args;
+    App::Memcached::CLI::Main->new(%$params)->run;
 
 =head1 DESCRIPTION
 
